==> linux-show-player_0.5.orig.tar.gz: linux-show-player-0.5/lisp/plugins/synchronizer/i18n/synchronizer_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>SyncPeerDialog</name>
    <message>
        <location filename="../peers_dialog.py" line="81"/>
        <source>Manage connected peers</source>
        <translation>Gestion des paires connectées</translation>
    </message>
    <message>
        <location filename="../peers_dialog.py" line="83"/>
        <source>Discover peers</source>
        <translation>Découvrir les paires</translation>
    </message>
    <message>
        <location filename="../peers_dialog.py" line="85"/>
        <source>Manually add a peer</source>
        <translation>Ajouter manuelement une paire</translation>
    </message>
    <message>
        <location filename="../peers_dialog.py" line="87"/>
        <source>Remove selected peer</source>
        <translation>Retirer la paire séléctionnée</translation>
    </message>
    <message>
        <location filename="../peers_dialog.py" line="89"/>
        <source>Remove all peers</source>
        <translation>Retirer toutes les paires</translation>
    </message>
    <message>
        <location filename="../peers_dialog.py" line="93"/>
        <source>Address</source>
        <translation>Adresses</translation>
    </message>
    <message>
        <location filename="../peers_dialog.py" line="93"/>
        <source>Peer IP</source>
        <translation>IP de la paire</translation>
    </message>
    <message>
        <location filename="../peers_dialog.py" line="105"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../peers_dialog.py" line="105"/>
        <source>Already connected</source>
        <translation>Déjà connecté</translation>
    </message>
    <message>
        <location filename="../peers_dialog.py" line="116"/>
        <source>Cannot add peer</source>
        <translation>Impossible d&apos;ajouter une paire</translation>
    </message>
</context>
<context>
    <name>Synchronizer</name>
    <message>
        <location filename="../synchronizer.py" line="38"/>
        <source>Synchronization</source>
        <translation>Synchronisation</translation>
    </message>
    <message>
        <location filename="../synchronizer.py" line="41"/>
        <source>Manage connected peers</source>
        <translation>Gérer les paiers connectées</translation>
    </message>
    <message>
        <location filename="../synchronizer.py" line="46"/>
        <source>Show your IP</source>
        <translation>Afficher votre IP</translation>
    </message>
    <message>
        <location filename="../synchronizer.py" line="63"/>
        <source>Your IP is:</source>
        <translation>Votre IP est : </translation>
    </message>
    <message>
        <location filename="../peers_discovery_dialog.py" line="55"/>
        <source>Discovering peers ...</source>
        <translation>Découverte des paires ...</translation>
    </message>
</context>
</TS>

==> linux-show-player_0.5.3.orig.tar.gz: linux-show-player-0.5.3/lisp/plugins/synchronizer/i18n/synchronizer_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>SyncPeerDialog</name>
    <message>
        <location filename="../peers_dialog.py" line="81"/>
        <source>Manage connected peers</source>
        <translation>Gestion des paires connectées</translation>
    </message>
    <message>
        <location filename="../peers_dialog.py" line="83"/>
        <source>Discover peers</source>
        <translation>Découvrir les paires</translation>
    </message>
    <message>
        <location filename="../peers_dialog.py" line="85"/>
        <source>Manually add a peer</source>
        <translation>Ajouter manuellement une paire</translation>
    </message>
    <message>
        <location filename="../peers_dialog.py" line="87"/>
        <source>Remove selected peer</source>
        <translation>Retirer la paire sélectionnée</translation>
    </message>
    <message>
        <location filename="../peers_dialog.py" line="89"/>
        <source>Remove all peers</source>
        <translation>Retirer toutes les paires</translation>
    </message>
    <message>
        <location filename="../peers_dialog.py" line="93"/>
        <source>Address</source>
        <translation>Adresses</translation>
    </message>
    <message>
        <location filename="../peers_dialog.py" line="93"/>
        <source>Peer IP</source>
        <translation>IP de la paire</translation>
    </message>
    <message>
        <location filename="../peers_dialog.py" line="105"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../peers_dialog.py" line="105"/>
        <source>Already connected</source>
        <translation>Déjà connecté</translation>
    </message>
    <message>
        <location filename="../peers_dialog.py" line="116"/>
        <source>Cannot add peer</source>
        <translation>Impossible d&apos;ajouter une paire</translation>
    </message>
</context>
<context>
    <name>Synchronizer</name>
    <message>
        <location filename="../synchronizer.py" line="38"/>
        <source>Synchronization</source>
        <translation>Synchronisation</translation>
    </message>
    <message>
        <location filename="../synchronizer.py" line="41"/>
        <source>Manage connected peers</source>
        <translation>Gérer les paires connectées</translation>
    </message>
    <message>
        <location filename="../synchronizer.py" line="46"/>
        <source>Show your IP</source>
        <translation>Afficher votre IP</translation>
    </message>
    <message>
        <location filename="../synchronizer.py" line="63"/>
        <source>Your IP is:</source>
        <translation>Votre IP est : </translation>
    </message>
    <message>
        <location filename="../peers_discovery_dialog.py" line="55"/>
        <source>Discovering peers ...</source>
        <translation>Découverte des paires ...</translation>
    </message>
</context>
</TS>
